### Name: GLMMARp.Binary
### Title: Markov Chain Monte Carlo for a Probit Multilevel Model with a
###   pth-order Autoregressive Error Process
### Aliases: GLMMARp.Binary
### Keywords: models

### ** Examples

 ## Not run: 
##D 
##D ## Example 1: GLMM-AR(p) model only with subject-specific and time-specific random intercepts
##D ##            and serial correlation; no group-level predictors
##D  
##D  data(StateFailure)
##D  require(bayesSurv)
##D  require(panel)
##D  y <- StateFailure$failure
##D  Unit <- StateFailure$country
##D  Time <- StateFailure$year
##D  Fixed <- cbind(StateFailure$poldemoc,  StateFailure$bnkv123, StateFailure$bnkv117, 
##D               StateFailure$poldurab, StateFailure$faocalry, StateFailure$pwtcgdp, 
##D               StateFailure$macnac,StateFailure$macnciv,  StateFailure$wdiinfmt, 
##D               StateFailure$ptsamnes, StateFailure$dis1, StateFailure$bnkv81, 
##D               StateFailure$change.demo)
##D   nphi <- 0.5
##D   nbeta <- 0
##D   nb <- 0
##D   nc <- 0
##D 
##D  UnitRandom <- as.matrix(rep( 1, length(y)))
##D  TimeRandom <- as.matrix(rep( 1, length(y)))
##D  UnitPred <- "NULL"
##D  TimePred <- "NULL"
##D 
##D  State0AR1 <- GLMMARp.Binary(y=y,X1=Fixed, Wi=UnitRandom, St=TimeRandom, Ai=UnitPred, Ft=TimePred,
##D                         Unit.Index=Unit, Time.Index=Time, timeint.add=0, unitint.add=0, m=1000,
##D                         burnin=500, init.phi=nphi, init.b=nb, init.c=nc, init.beta=nbeta, 
##D                         beta0=rep(0,13),B0=diag(10, 13),
##D                         D0=1.67 ,E0=6, e0=5, d0=5,  pgm=TRUE, nlag=1, tracking=5,
##D                         monitor=c("rho", "beta", "bi", "ct", "D", "E", "ystar", "u"), 
##D                         marginal.likelihood=TRUE, reduced.mcmc=500, reduced.burnin=100, thin=1)
##D 
##D ## Example 2: GLMM-AR(p) model with a subject-specific coefficient, random intercepts
##D ##            and serial correlation; no group-level predictors
##D 
##D  UnitRandom <- cbind(log(StateFailure$pwtopen))
##D  TimeRandom <- as.matrix(rep( 1, length(y)))
##D  UnitPred <- "NULL"
##D  TimePred <- "NULL"
##D 
##D StateAR1 <- GLMMARp.Binary(y=y,X1=Fixed, Wi=UnitRandom, St=TimeRandom, Ai=UnitPred, Ft=TimePred,
##D                         Unit.Index=Unit, Time.Index=Time, timeint.add=0, unitint.add=1, m=1000,
##D                         burnin=500, init.phi=nphi, init.b=nb,
##D                         init.c=nc, init.beta=nbeta,beta0=rep(0,14),B0=diag(10, 14),
##D                         D0=diag(1.67,2) ,E0=6,e0=3, d0=4,  pgm=TRUE, nlag=1, tracking=5,
##D                         monitor=c("rho", "beta", "bi", "ct", "D", "E", "ystar", "u"), 
##D                         marginal.likelihood=TRUE, reduced.mcmc=500, reduced.burnin=100,thin=1)
##D 
##D ## Example 3: GLMM-AR(p) model with a subject-specific coefficient, random intercepts
##D ##            and serial correlation; only subject-level predictors.
##D 
##D  TimeRandom <- as.matrix(rep( 1, length(y)))
##D  UnitPred <- cbind(StateFailure$macnac, StateFailure$poldemoc)
##D  TimePred <- "NULL"
##D  nphi <- c(0.2, 0.1)
##D 
##D  StateAR2 <- GLMMARp.Binary(y=y,X1=Fixed, Wi=UnitRandom, St=TimeRandom, Ai=UnitPred, Ft=TimePred,
##D                         Unit.Index=Unit, Time.Index=Time, timeint.add=0, unitint.add=1, m=1000,
##D                         burnin=500, init.phi=nphi, init.b=nb,
##D                         init.c=nc, init.beta=nbeta,beta0=rep(0,15),B0=diag(10, 15),
##D                         D0=diag(1.67,2) ,E0=6,e0=5, d0=6, pgm=TRUE, nlag=2, tracking=5,
##D                         monitor=c("rho", "beta", "bi", "ct", "D", "E", "ystar", "u"), 
##D                         marginal.likelihood=TRUE, reduced.mcmc=500, reduced.burnin=100, thin=1)
##D 
##D ## Example 3: GLMM-AR(p) model with a subject-specific coefficient, random intercepts
##D ##            and serial correlation; with both subject- and time-level predictors.
##D 
##D  TimePred <- cbind(StateFailure$dis1)
##D  nphi <- c(0.3, 0.1, 0.1)
##D 
##D StateAR3 <- GLMMARp.Binary(y=y,X1=Fixed, Wi=UnitRandom, St=TimeRandom, Ai=UnitPred, Ft=TimePred,
##D                         Unit.Index=Unit, Time.Index=Time, timeint.add=1, unitint.add=1, m=1000,
##D                         burnin=500, init.phi=nphi, init.b=nb,
##D                         init.c=nc, init.beta=nbeta,beta0=rep(0,16),B0=diag(10, 16),
##D                         D0=diag(1.67,2) ,E0=diag(1.67,2),e0=5, d0=6, pgm=TRUE, nlag=3, tracking=5,
##D                         monitor=c("rho", "beta", "bi", "ct", "D", "E", "ystar", "u"), 
##D                         marginal.likelihood=TRUE, reduced.mcmc=500, reduced.burnin=100, thin=1)
##D 
## End(Not run)



